Stan Math Library: stan/math/prim/mat/fun/trace.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
trace.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T | stan::math::trace (const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
| Returns the trace of the specified matrix. More...
template<typename T >
T | stan::math::trace (const T &m)

[ Stan Home Page ] © 2011–2016, Stan Development Team.